# DaDRA
[![Documentation Status](https://readthedocs.org/projects/dadra/badge/?version=latest)](https://dadra.readthedocs.io/en/latest/?badge=latest)
[![PyPI Latest Release](https://img.shields.io/pypi/v/dadra.svg)](https://pypi.org/project/dadra/)
[![License](https://img.shields.io/pypi/l/dadra.svg)](https://github.com/dadra/blob/master/LICENSE)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

Python Library for Data-Driven Reachability Analysis.

## Installation
To install the current release of `dadra`:
```
$ pip install --upgrade dadra
```

## Resources
* [PyPi](https://pypi.org/project/dadra/)
* [Documentation](https://dadra.readthedocs.io/en/latest/)
* [Issue tracking](https://github.com/JaredMejia/dadra/issues)

## License
[MIT License](https://github.com/JaredMejia/dadra/blob/main/LICENSE)

## BibTeX
```bibtex
@article{JaredMejia,
  title={DaDRA},
  author={Mejia, Jared},
  journal={GitHub. Note: https://github.com/JaredMejia/dadra},
  volume={1},
  year={2021}
}
```
